@@ -26,7 +26,7 @@ Generic Access to Thruks Config
 
 ######################################
 
-our $VERSION = '3.25.20251231';
+our $VERSION = '3.25.20260108';
 our $GIT_HASH = "24a7b12a6"; # set by dailydist make target
 
 our $config;
@@ -35,7 +35,7 @@ our $project_root = home() || confess('could not determine project_root from inc
 my $base_defaults = {
     'name'                                  => 'Thruk',
     'fileversion'                           => $VERSION,
-    'released'                              => 'December 31, 2025',
+    'released'                              => 'January 08, 2026',
     'compression_format'                    => 'gzip',
     'ENCODING'                              => 'utf-8',
     'image_path'                            => $project_root.'/root/thruk/images',
